@@ -9,6 +9,7 @@ use pruning::is_pruned_branch;
 #[clap(version, about, author)]
 enum Cli {
     /// Create a new branch from HEAD and push it to origin.
+    /// Set a prefix for all new branch names with the env var LOKI_NEW_PREFIX
     #[clap(visible_alias = "n")]
     New {
         /// List of names to join with dashes to form a valid branch name.
@@ -39,12 +40,19 @@ fn main() -> Result<(), String> {
     }
 }
 
+const LOKI_NEW_PREFIX: &str = "LOKI_NEW_PREFIX";
+
 fn new_branch(name: &Vec<String>) -> Result<(), String> {
     if name.len() == 0 {
         return Err(String::from("name cannot be empty."));
     }
 
-    let name = name.join("-");
+    let mut name = name.join("-");
+
+    if let Ok(prefix) = std::env::var(LOKI_NEW_PREFIX) {
+        eprintln!("Using prefix from env var {LOKI_NEW_PREFIX}={prefix}");
+        name = format!("{prefix}{name}");
+    }
 
     git::git_commands_status(vec![
         (
